@@ -28,7 +28,15 @@ default_list = {
     '940824': {
         'command': '魔法人生',
         'title': '魔法人生：我在霍格沃兹读书时发生的两三事'
-    }
+    },
+    '1075116': {
+        'command': '抽老婆',
+        'title': 'あなたの二次元での嫁ヒロイン'
+    },
+    '400813': {
+        'command': '抽舰娘',
+        'title': '【艦これ】あなたの嫁になる艦娘は？'
+    },
 }
 
 
